//IPR data construction

//(1) Download ITPD-E file from https://www.usitc.gov/data/gravity/itpd_e_r01.zip
//ID vars: exporter_iso3 importer_iso3 year industry_id 
// This dataset contains the gravity trade data

//(2) Download dynamic gravity covariates from 
https://www.usitc.gov/data/gravity/dgd_docs/release_2.1_2000_2019.zip
// this dataset contains the agree_fta variable which are needed to construct the FTA dummies

//(3) Download Morin & Surbeck TRIPS plus dataset from
https://www.designoftradeagreements.org/media/filer_public/b6/c5/b6c555bc-b584-463f-b927-617a1702ec78/tpta_codebook_dataset.xlsx
// this dataset contains the TRIPSplus data

//(4) Download Morin & Surbeck IPR dataset from 
https://www.designoftradeagreements.org/media/filer_public/89/a5/89a58d38-ac92-45c8-a7e7-b6a7b87c9ab8/iprs_in_ptas_codebook_dataset.xlsx
// this dataset contains the general IPR data for agreements with IPR but not TRIPS plus

//(5) The Morin & Surbeck datasets must be converted to gravity form using the dyadic list from DESTA
(https://www.designoftradeagreements.org/media/filer_public/8d/56/8d56dfb3-5bcc-4e8d-8d2a-39bc8333155e/desta_list_of_treaties_02_00_dyads_data.csv), keeping only WTO listed agreements for consistency with other models in this report

//(6) Create a dummy variable for IP intense sectors using the USPTO publication "Intellectual Property and the US economy" from https://www.uspto.gov/learning-and-resources/ip-motion/intellectual-property-and-us-economy

//(7) Merge datasets

//(8) constuct FTA variables

mvencode ipr* patent*, mv(-99)
recode ipr* patent* (-99=0)

encode exporter_iso3, gen(exp_num)
encode importer_iso3, gen(imp_num)

gen ipr_tripsplus_dummy=1 if ipr_tripsplus_per_pta>0
replace ipr_tripsplus_dummy=0 if missing(ipr_tripsplus_dummy)

gen fta_any_ipr = 1 if agree_fta==1 & ipr_general_ipr_dummy==1 & ipr_tripsplus_dummy==0
replace fta_any_ipr = 0 if missing(fta_any_ipr)

gen fta_trips_plus = 1 if agree_fta==1  & ipr_tripsplus_dummy==1
replace fta_trips_plus=0 if missing(fta_trips_plus)

gen fta_no_ip =1 if agree_fta==1& fta_any_ipr==0 & ipr_tripsplus_dummy==0
replace fta_no_ip = 0 if missing(fta_no_ip)

gen fta_ipr_no_tripsplus = 1 if fta_any_ipr==1 & fta_trips_plus==0
replace fta_ipr_no_tripsplus=0 if missing(fta_ipr_no_tripsplus)

gen USA = 1 if exporter_iso3=="USA" | importer_iso3=="USA"
replace USA=0 if missing(USA)

gen US_TRIPSplus = 1 if USA==1 & ipr_tripsplus_dummy==1
replace US_TRIPSplus=0 if missing(US_TRIPSplus)

gen TRIPSplus_no_US = 1 if USA==0 & ipr_tripsplus_dummy==1
replace TRIPSplus_no_US =0 if missing(TRIPSplus_no_US )

//(9) create lags
foreach var of varlist  ipr_tripsplus_dummy gen fta_no_ip gen fta_ipr_no_tripsplus gen US_TRIPSplus gen TRIPSplus_no_US {
	sort exporter_iso3 importer_iso3 industry_id year 
	bysort exporter_iso3 importer_iso3 industry_id : gen `var'_3 = `var'[_n-3]
}



