*Do-File to Create Labor Shares for GTAP Labor Disaggregation

*The labor shares calculated in this do file accompany the report "Economic Impact of Trade Agreements Implemented Under Trade Authorities Procedures, 2021 Report, Inv. TPA-105-008". The labor shares were calculated to match the structure of the labor model in Johnson and Keane (2013), and were used in the CGE model employed in the economy-wide analysis of the report. Given the limited time frame of the investigation, it may be possible to further refine sector-specific shares with additional data sources.

clear
cd "<working file path>"

******Download CPS ASEC survey data from IPUMS******

use cps2017.dta  /*CPS ASEC survey can be downloaded here:https://cps.ipums.org/cps/ */

*Drop unemployed from dataset 
drop if occly==0

******Arrange data by gender, education level, and occupation group******

*Education groups (note highschool=1, college=2) 
tabulate educ, gen(educgroup)
gen educlevel = 1
replace educlevel = 2 if educgroup10==1
replace educlevel = 2 if educgroup11==1
replace educlevel = 2 if educgroup12==1
replace educlevel = 2 if educgroup13==1
replace educlevel = 2 if educgroup14==1
replace educlevel = 2 if educgroup15==1
replace educlevel = 2 if educgroup16==1
drop educgroup*

*Gender groups (note male=1, female=2)
tabulate sex, gen(gendergroup)
gen gender = 1
replace gender = 2 if gendergroup2 == 1
drop gendergroup*

*Occupation groups (to match Johnson and Keane, CPS groups)
merge m:1 occly using occly_concord_udpated 
/*this is a file that maps each 4-digit occupation code (occly) to the 5 census groups, with some re-arranging from census group 1 to 2 to match Johnson and Keane. Classifications found here: https://www2.census.gov/programs-surveys/cps/methodology/Occupation%20Codes.pdf
*/
drop if occly==9840 /*military occupations not included in estimation*/
sort _merge
drop if _merge==2
tab occly if _merge==1 /*Add any new census occupations if unmapped*/
drop _merge 

******Map industry codes to GTAP sectors, via NAICS******

merge m:1 indly using indly_concord_udpated
/*Mapping: https://www2.census.gov/programs-surveys/cps/methodology/Industry%20Codes.pdf*/
sort _merge
drop if _merge==2
tab indly if _merge==1 /*Add any new industry-naics combinations if unmapped*/
drop _merge

*Concord NAICS codes to GTAP sectors 

merge m:1 naics using gtap_concord_udpated 
/*this is a concordance that maps each naics code to a gtap sector*/
sort _merge
drop if _merge==2
tab naics if _merge==1 /*Add any new naics-gtap combinations if unmapped*/
drop _merge

******Create labor shares for each gtap sector and labor type****** 

gen cps_id = _n 
keep cps_id gender educlevel occgroup gtap naics incwage
order cps_id gender educlevel occgroup gtap naics
save cpsdata_edited, replace

gen labor_id ="blank" 
replace labor_id = "FCOL1" if gender==2 & educlevel==2 & occgroup==1 
replace labor_id = "FCOL2" if gender==2 & educlevel==2 & occgroup==2
replace labor_id = "FCOL3" if gender==2 & educlevel==2 & occgroup==3
replace labor_id = "FCOL4" if gender==2 & educlevel==2 & occgroup==4
replace labor_id = "FCOL5" if gender==2 & educlevel==2 & occgroup==5
replace labor_id = "MCOL1" if gender==1 & educlevel==2 & occgroup==1
replace labor_id = "MCOL2" if gender==1 & educlevel==2 & occgroup==2
replace labor_id = "MCOL3" if gender==1 & educlevel==2 & occgroup==3
replace labor_id = "MCOL4" if gender==1 & educlevel==2 & occgroup==4
replace labor_id = "MCOL5" if gender==1 & educlevel==2 & occgroup==5
replace labor_id = "FHS1" if gender==2 & educlevel==1 & occgroup==1
replace labor_id = "FHS2" if gender==2 & educlevel==1 & occgroup==2
replace labor_id = "FHS3" if gender==2 & educlevel==1 & occgroup==3
replace labor_id = "FHS4" if gender==2 & educlevel==1 & occgroup==4
replace labor_id = "FHS5" if gender==2 & educlevel==1 & occgroup==5
replace labor_id = "MHS1" if gender==1 & educlevel==1 & occgroup==1
replace labor_id = "MHS2" if gender==1 & educlevel==1 & occgroup==2
replace labor_id = "MHS3" if gender==1 & educlevel==1 & occgroup==3
replace labor_id = "MHS4" if gender==1 & educlevel==1 & occgroup==4
replace labor_id = "MHS5" if gender==1 & educlevel==1 & occgroup==5

* Wage Bill Shares (stata database and latex table)
preserve
collapse (sum) wagebill=incwage, by(labor_id gtap)
order gtap labor_id wagebill
sort gtap labor_id
by gtap: egen sumwage = total(wagebill)
gen wageshare = wagebill/sumwage
drop sumwage wagebill
format wageshare %9.4f
reshape wide wageshare, i(labor_id) j(gtap) string
foreach var of varlist wageshare* {
   	local newname = substr("`var'", 10, .)
   	rename `var' `newname'
}
/*Some missing sectoral coverage for ag sectors because indly does not have enough ag detail, so assume the shares are the same across all crops, all animals*/
gen omt = cmt
gen oap = ctl
gen rmk = ctl
gen gas = oil
gen pdr = osd
gen wht = osd
gen gro = osd
gen v_f = osd
gen c_b = osd
gen pfb = osd
gen ocr = osd
gen vol = pcr
order _all, alphabetic
order labor_id
save wagebillshares.dta, replace
estpost tabstat afs atp b_t bph c_b chm cmn cmt cns coa ctl edu eeq ele ely fmp frs fsh gas gdt gro hht i_s ins lea lum mil mvh nfm nmm oap obs ocr ofd ofi oil ome omf omt osd osg otn otp oxt p_c pcr pdr pfb ppp rmk ros rpp rsa sgr tex trd v_f vol wap whs wht wol wtp wtr, by(labor_id) 
matrix A = e(afs)', e(atp)', e(b_t)', e(bph)', e(c_b)', e(chm)', e(cmn)', e(cmt)', e(cns)', e(coa)', e(ctl)', e(edu)', e(eeq)', e(ele)', e(ely)', e(fmp)', e(frs)', e(fsh)', e(gas)', e(gdt)', e(gro)', e(hht)', e(i_s)', e(ins)', e(lea)', e(lum)', e(mil)', e(mvh)', e(nfm)', e(nmm)', e(oap)', e(obs)', e(ocr)', e(ofd)', e(ofi)', e(oil)', e(ome)', e(omf)', e(omt)', e(osd)', e(osg)', e(otn)', e(otp)', e(oxt)', e(p_c)', e(pcr)', e(pdr)', e(pfb)', e(ppp)', e(rmk)', e(ros)', e(rpp)', e(rsa)', e(sgr)', e(tex)', e(trd)', e(v_f)', e(vol)', e(wap)', e(whs)', e(wht)', e(wol)', e(wtp)', e(wtr)'
esttab matrix(A, fmt(3)) using wagebillshares.tex, title("Wage Bill Share Matrix") replace 
restore

*Mean Wages by Sector and Labor Type (stata dataset and latex Table)
preserve
collapse (mean) meanwage=incwage, by(labor_id gtap)
order gtap labor_id meanwage
sort gtap labor_id
reshape wide meanwage, i(labor_id) j(gtap) string
foreach var of varlist meanwage* {
   	local newname = substr("`var'", 9, .)
   	rename `var' `newname'
}
/*Some missing sectoral coverage for ag sectors because indly does not have enough ag detail, so assume the shares are the same across all crops, all animals*/
gen omt = cmt
gen oap = ctl
gen rmk = ctl
gen gas = oil
gen pdr = osd
gen wht = osd
gen gro = osd
gen v_f = osd
gen c_b = osd
gen pfb = osd
gen ocr = osd
gen vol = pcr
order _all, alphabetic
order labor_id
save meanwages.dta, replace
estpost tabstat afs atp b_t bph c_b chm cmn cmt cns coa ctl edu eeq ele ely fmp frs fsh gas gdt gro hht i_s ins lea lum mil mvh nfm nmm oap obs ocr ofd ofi oil ome omf omt osd osg otn otp oxt p_c pcr pdr pfb ppp rmk ros rpp rsa sgr tex trd v_f vol wap whs wht wol wtp wtr, by(labor_id) 
matrix A = e(afs)', e(atp)', e(b_t)', e(bph)', e(c_b)', e(chm)', e(cmn)', e(cmt)', e(cns)', e(coa)', e(ctl)', e(edu)', e(eeq)', e(ele)', e(ely)', e(fmp)', e(frs)', e(fsh)', e(gas)', e(gdt)', e(gro)', e(hht)', e(i_s)', e(ins)', e(lea)', e(lum)', e(mil)', e(mvh)', e(nfm)', e(nmm)', e(oap)', e(obs)', e(ocr)', e(ofd)', e(ofi)', e(oil)', e(ome)', e(omf)', e(omt)', e(osd)', e(osg)', e(otn)', e(otp)', e(oxt)', e(p_c)', e(pcr)', e(pdr)', e(pfb)', e(ppp)', e(rmk)', e(ros)', e(rpp)', e(rsa)', e(sgr)', e(tex)', e(trd)', e(v_f)', e(vol)', e(wap)', e(whs)', e(wht)', e(wol)', e(wtp)', e(wtr)'
esttab matrix(A, fmt(3)) using meanwages.tex, title("Mean Wages by Labor Type and Sector") replace 
restore

