* ------
* Gravity estimation for FAO database
* ------

* Description: Script first runs model for aggregate trade, then loops through each sector and runs model. 
*	 Estimates are stored as individual files for each sector. Note that even on a high-performance 
* 	 computer, estimates may take several hours to complete in full. 

** 
* Aggregate Trade
**
cd "goods_estimation_code_release"
use "fao_sample.dta", clear

keep if gtap == "aggregate"

* Create country-year fixed effects
egen exp_time = group(exporter_iso3 year)
egen imp_time = group(importer_iso3 year)


* Create time varrying same country dummies
tab year, generate(yr)
foreach col of varlist yr*{
	gen smctry_`col'=`col'*smctry
}
drop yr*

* Run regression
ppmlhdfe trade smctry_yr* member_gatt_joint member_eu_joint agree_fta_no_tpa United_States_Israel CUSFTA NAFTA member_wto_joint United_States_Jordan United_States_Singapore United_States_Chile United_States_Australia United_States_Morocco United_States_Bahrain CAFTA_DR United_States_Oman United_States_Peru KORUS United_States_Columbia United_States_Panama, absorb(exp_time imp_time pair_id) cluster(pair_id) d(fe_sum)
* Save output
parmest, saving(aggregate_estimates\fao_estimates_aggregate, replace) stars(0.1 0.05 0.01)


**
* By Sector
**

use "fao_sample.dta", clear

* Create country-year fixed effects
egen exp_time = group(exporter_iso3 year)
egen imp_time = group(importer_iso3 year)


* Create time varrying same country dummies
tab year, generate(yr)
foreach col of varlist yr*{
	gen smctry_`col'=`col'*smctry
}
drop yr*

* Relable sector to get rid of space
replace gtap = "oil_gas" if gtap == "oil & gas"


* Loop through each sector
foreach sect in  "c_b" "cmt" "gro" "oap" "ocr" "omt" "osd" "pfb" "rmk" "tex" "v_f" "vol" "wht" "wol"{
display "sector `sect' beginning"
* Run regression
ppmlhdfe trade smctry_yr* member_gatt_joint member_eu_joint agree_fta_no_tpa United_States_Israel CUSFTA NAFTA member_wto_joint United_States_Jordan United_States_Singapore United_States_Chile United_States_Australia United_States_Morocco United_States_Bahrain CAFTA_DR United_States_Oman United_States_Peru KORUS United_States_Columbia United_States_Panama if gtap=="`sect'", absorb(exp_time imp_time pair_id) cluster(pair_id)
* Store output
parmest, saving(fao_sector_estimates\fao_estimates_`sect', replace) stars(0.1 0.05 0.01)
display "Sector `sect' complete!"
}

