* ------
* Gravity estimation for ITPD-E database
* ------

* Description: Script first runs model for aggregate trade, then loops through each sector and runs model. 
*	 Estimates are stored as individual files for each sector. Note that even on a high-performance 
* 	 computer, estimates may take several hours to complete in full. 

** 
* Aggregate Trade
**
cd "goods_estimation_code_release"
use "itpd_sample.dta", clear

keep if gtap == "aggregate"

* Create country-year fixed effects
egen exp_time = group(exporter_iso3 year)
egen imp_time = group(importer_iso3 year)


* Create time varrying same country dummies
tab year, generate(yr)
foreach col of varlist yr*{
	gen smctry_`col'=`col'*smctry
}
drop yr*

* Run Regression
ppmlhdfe trade smctry_yr* member_eu_joint agree_fta_no_tpa member_wto_joint United_States_Israel NAFTA United_States_Jordan United_States_Singapore United_States_Chile United_States_Australia United_States_Morocco United_States_Bahrain CAFTA_DR United_States_Oman United_States_Peru KORUS United_States_Columbia United_States_Panama, absorb(exp_time imp_time pair_id) cluster(pair_id) d(fe_sum)
* Store Estimates
parmest, saving("aggregate_estimates\itpd_estimates_aggregate", replace) stars(0.1 0.05 0.01)


**
* By Sector
**

* Reload data
use "itpd_sample.dta", clear

* Create country-year fixed effects
egen exp_time = group(exporter_iso3 year)
egen imp_time = group(importer_iso3 year)


* Create time varrying same country dummies
tab year, generate(yr)
foreach col of varlist yr*{
	gen smctry_`col'=`col'*smctry
}
drop yr*

replace gtap = "oil_gas" if gtap == "oil & gas"

* Loop through each sector and perform gravity analysis.
* Sectors "gdt" and "whs" omitted due to convergence issues.
foreach sect in "b_t" "bph" "c_b" "chm" "cmt" "ctl" "eeq" "ele" "ely" "fmp" "gro" "i_s" "lea" "lum" "mil" "mvh" "nfm" "nmm" "oap" "ocr"  "ofd" "oil_gas" "ome" "omf" "omt" "osd" "otn" "p_c" "pdr" "pfb" "ppp" "rpp" "sgr" "tex" "v_f" "vol" "wap" "wht" "wol" {
display "sector `sect' beginning"
* Run Regression
ppmlhdfe trade smctry_yr* member_eu_joint agree_fta_no_tpa member_wto_joint United_States_Israel NAFTA United_States_Jordan United_States_Singapore United_States_Chile United_States_Australia United_States_Morocco United_States_Bahrain CAFTA_DR United_States_Oman United_States_Peru KORUS United_States_Columbia United_States_Panama if gtap=="`sect'", absorb(exp_time imp_time pair_id) cluster(pair_id)
* Store estimates
parmest, saving(itpd_sector_estimates\itpd_estimates_`sect', replace) stars(0.1 0.05 0.01)
display "Sector `sect' complete!"
}

