__Description__ = '''Combine the ITPD and TradeProde and FAO AVE estimates into a single table.'''


import pandas as pd


# ---
# Set Specs
# ----

# Set path locations for the files produced by steps 1b, 2b, and 3b, respectively.
fao_ave_file = "goods_estimation_code_release/ave_estimates/ave_estimates_fao.csv"
tradeprod_ave_file = "goods_estimation_code_release/ave_estimates/ave_estimates_tradeprod.csv"
itpd_ave_file = "goods_estimation_code_release/ave_estimates/ave_estimates_itpd.csv"


# Select PTAs to collect from each set of estimates
itpd_ptas = ['United_States_Singapore', 'United_States_Chile', 'United_States_Australia', 'United_States_Morocco',
             'United_States_Bahrain', 'CAFTA_DR', 'United_States_Oman', 'United_States_Peru', 'KORUS',
             'United_States_Columbia',
             'United_States_Panama']
tradeprod_ptas = ['United_States_Israel', 'CUSFTA', 'NAFTA', 'United_States_Jordan', 'member_wto_joint']
fao_ptas = ['NAFTA', 'United_States_Jordan', 'member_wto_joint']

# Leave out FAO sectors that appear in the TradeProd data E.g. 'tex' is mostly manufacturing (TradeProd) but does have
#   some agricultural products in it (FAO). For this reason, the TradeProd estimates are likely more appropriate.
fao_unused_sectors = ['tex']

# Save location
save_local = "goods_estimation_code_release/ave_estimates/"




# ----
# Create Combined AVE Table
# ----

# Load ave tables
itpd_aves = pd.read_csv(itpd_ave_file)
tradeprod_aves = pd.read_csv(tradeprod_ave_file)
fao_aves = pd.read_csv(fao_ave_file)

# Drop p-value columns
itpd_ave_cols = [col for col in itpd_aves.columns if not col.startswith('p')]
itpd_aves = itpd_aves[itpd_ave_cols]

tradeprod_ave_cols = [col for col in tradeprod_aves.columns if not col.startswith('p')]
tradeprod_aves = tradeprod_aves[tradeprod_ave_cols]

fao_ave_cols = [col for col in fao_aves.columns if not col.startswith('p')]
fao_aves = fao_aves[fao_ave_cols]

# clean up header rows
itpd_aves.columns = itpd_aves.loc[0,:]
itpd_aves.drop([0,1], axis=0, inplace = True)

tradeprod_aves.columns = tradeprod_aves.loc[0, :]
tradeprod_aves.drop([0, 1], axis=0, inplace=True)

fao_aves.columns = fao_aves.loc[0, :]
fao_aves.drop([0, 1], axis=0, inplace=True)

# Subset on desired pta estimates for each dataset and prepare for combining all three
itpd_aves = itpd_aves[['parm'] + itpd_ptas]
tradeprod_aves = tradeprod_aves[['parm']+ tradeprod_ptas]
tradeprod_aves.loc[tradeprod_aves['parm']=='aggregate','parm'] = 'mnf_aggregate'
fao_aves = fao_aves[['parm']+ fao_ptas]
fao_aves.loc[fao_aves['parm']=='aggregate','parm'] = 'agr_aggregate'
fao_aves = fao_aves.loc[~fao_aves['parm'].isin(fao_unused_sectors),:]


# Combine
early_aves = pd.concat([fao_aves,tradeprod_aves], axis = 0)
combined = early_aves.merge(itpd_aves, how = 'outer', on = 'parm', validate='1:1')
combined.to_csv("{}ave_estimates_combined.csv".format(save_local), index = False)





