* File to clean and merge original ITPD, WB FTA data and Dynamic Gravity Database 
********************************************************
//(1) Download ITPD-E file from https://www.usitc.gov/data/gravity/itpde.htm 
import delimited ITPD_E_R01.csv
keep exporter_iso3 importer_iso3 year industry_id industry_descr trade flag_zero
keep if industry_id>=154 //Drop all non-services sectors
sort exporter_iso3 importer_iso3 industry_id year
save itpd_services, replace

//(2) Use excel file "WB-dataset-on-the-intensive-margin-july-2020" provided  
//(2a) Transpose the State worksheet with agrements on rows and provisions in columns
import excel "WB-dataset-on-the-intensive-margin-july-2020.xlsx", sheet("STATA") firstrow clear
replace Coding= subinstr(Coding, " ", "", .) //remove spaces 
drop Area Section Subsection Provision  
tostring agree_76 agree_103 agree_121 agree_216 , replace format(%2.0f) //convert all variables to string
reshape long agree_, i(Coding) j(id)

//Reduce length of variable names to 32 chars
gen WB_Coding= subinstr(Coding, "Anti-dumping", "Antidumping", .)
replace WB_Coding= subinstr(WB_Coding, "Countervailingduties", "CVD", .)
replace WB_Coding= subinstr(WB_Coding, "-", "_", .)
drop Coding
rename agree_ A_
reshape wide A_, i(id) j(WB_Coding) string
rename (A_* ) (*)
save WB_provisions, replace  //file contains 283 FTAs (rows) with 1028 WB-coded provisions (columns)

//(2b) Import worksheet labelled "Bilateral Information" for country and year information and merge with WB_provisions
import excel "WB-dataset-on-the-intensive-margin-july-2020.xlsx", sheet("Bilateral Information") firstrow clear
merge m:1 id using WB_provisions
keep if _merge==3
drop _merge
drop if year<2000 | year==2017 //Match ITPD-E years
sort iso1 iso2 year

//(3) Rules to resolve overlapping agreements bw country pairs in WB_prov_bilat file
//(3a) Keep agreements with the most lib services provision for each ctry pair year
duplicates tag iso1 iso2 year, gen(isdup1) //all overlapping agreements bw ctry pairs

replace Services_s_lib_app="3" if Services_s_lib_app=="B"
replace Services_s_lib_app="2" if Services_s_lib_app=="C"
replace Services_s_lib_app="1" if Services_s_lib_app=="A"
replace Services_othdip_lpr="." if Services_othdip_lpr=="NA"
destring Services_s_lib_app Services_s_lib_rat Services_s_lib_stand Services_dis_nt Services_othdip_lpr,replace

egen Services_composite=rowtotal(Services_s_lib_app Services_s_lib_rat Services_s_lib_stand Services_dis_nt Services_othdip_lpr)
bysort iso1 iso2 year: egen max_lib=max(Services_composite) if isdup1
drop if Services_composite!=max_lib & isdup1
drop isdup1 Services_composite 

//(3b) Keep agreements with most non-missing services provision for each ctry pair year
duplicates tag iso1 iso2 year, gen(isdup2) 
tostring Services*, replace format(%2.0f) //Check if Services provisions with missing data correctly coded
foreach v of varlist Services* { 
    replace `v' = "" if `v' == "."
}
egen Services_Nomissing = rownonmiss(Services*),strok //non-zero means atleast one Services provision coded
bysort iso1 iso2 year: egen max_nomiss=max(Services_Nomissing) if isdup2
drop if Services_Nomissing!=max_nomiss & isdup2
drop isdup2

//(3c) Keep agreements with latest entry date
duplicates tag iso1 iso2 year, gen(isdup3) 
bysort iso1 iso2 year: egen max_year=max(entry_force) if isdup3
drop if entry_force!=max_year & isdup3
drop isdup3

//(3d) Drop agreements coded with different names
sort iso1 iso2 agreement year 
duplicates drop iso1 iso2 year, force
drop max* 

//(4) Drop all non-services provisions and balance panel with missing years
ds
keep iso1 iso2 year agreement entry_force type id Services*
gen cpair=iso1+"_"+iso2
encode cpair, gen(ctry_pair)
drop cpair

xtset ctry_pair year
tsfill,full
decode ctry_pair, generate(iso_pair)
replace iso1=substr(iso_pair,1,3) if iso1==""
replace iso2=substr(iso_pair,5,7) if iso2==""
replace Services_Nomissing=0 if Services_Nomissing==. //Account for new observations added to panel
drop ctry_pair iso_pair

//(5) Fix missing US-Dominican Republic agreement in WB database 
rename (iso1 iso2) (exporter_iso3 importer_iso3)
expand 2 if exporter_iso3=="USA" & importer_iso3=="CRI", gen(us_dom)
replace importer_iso3="DOM" if us_dom

expand 2 if exporter_iso3=="CRI" & importer_iso3=="USA", gen(dom_us)
replace exporter_iso3="DOM" if dom_us
drop us_dom dom_us

sort exporter_iso3 importer_iso3 year
save WB_services_clean, replace

//(6) Merge WB with ITPD-E
use itpd_services,clear
merge m:1 exporter_iso3 importer_iso3 year using WB_services_clean, gen(WB_merge)
drop if WB_merge==2 //No ITPD data for these country pairs

//Supplement WB PTAs with Dynamic Gravity Data Version 2.0 (download from https://www.usitc.gov/data/gravity/dgd.htm)
merge m:1 exporter_iso3 importer_iso3 year using release_2_2000_2016, gen(DGD_merge) keepusing(agree* member*)
drop if DGD_merge==1 | DGD_merge==2 //No ITPD data for these country pairs 

//Country pairs in ITPD-E that have agreements recorded in DGD but not WB 
count if agree_fta==1 & WB_merge==1 // 371 observations
count if agree_pta_goods==1 & WB_merge==1 // 371 observations
count if agree_pta_services==1 & WB_merge==1 // 0 observations
count if agree_cu==1 & WB_merge==1 // 0 observations
count if agree_eia==1 & WB_merge==1 // 0 observations
replace type="FTA" if WB_merge==1 & agree_fta==1 //Capture that 371 ITPD observations have an FTA in goods 

drop agree_* member* DGD_merge
save itpd_wb_services, replace //Main data file used in model_estimation





 
